#
# spec file for package c-toxcore
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013 Markus Kolb, Innsbruck, Austria.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines
%define _soversion 2
Name:           c-toxcore
Version:        0.2.2
Release:        lp150.1.1
Summary:        Secure decentralized instant messaging application
License:        GPL-3.0
Group:          Productivity/Networking/Instant Messenger
Url:            https://tox.chat/
Source0:        https://github.com/TokTok/c-toxcore/archive/v%{version}.tar.gz#./%{name}-%{version}.tar.gz
Source1:        %{name}.tmpfiles.d
Source2:        https://github.com/TokTok/c-toxcore/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libconfig-devel
BuildRequires:  libopus-devel
BuildRequires:  libsodium-devel
BuildRequires:  libtool
BuildRequires:  libvpx-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(systemd)
Requires(pre):  shadow
%{?systemd_requires}

%description
Project Tox, also known as Tox, is a FOSS instant messaging
application aimed to replace Skype.
With the rise of government monitoring programs,
Tox provides an easy to use application that allows you to connect
with friends and family without anyone else listening in.
While other big-name services require you to pay for features,
Tox is totally free and comes without advertising

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libtoxav%{_soversion} = %{version}
Requires:       libtoxcore%{_soversion} = %{version}
Requires:       libtoxencryptsave%{_soversion} = %{version}

%description devel
Development libraries and headers needed to build software using %{name}.

%package daemon
Summary:        Bootstrap-daemon for toxcore
Group:          Productivity/Networking/Instant Messenger

%description daemon
Bootstrap-daemon to dispose hashtable for toxcore.

%package -n libtoxav%{_soversion}
Summary:        Audio/Video library for toxcore
Group:          System/Libraries

%description -n libtoxav%{_soversion}
This are the Audio/Video library for toxcore.

%package -n libtoxcore%{_soversion}
Summary:        Core library for toxcore
Group:          System/Libraries

%description -n libtoxcore%{_soversion}
This are the Core library for toxcore.

%package -n libtoxencryptsave%{_soversion}
Summary:        Encrypt Save library for toxcore
Group:          System/Libraries

%description -n libtoxencryptsave%{_soversion}
This are the Encrypt Save library for toxcore.

%prep
%setup -q
# change location of bootstrap bin
sed -ri 's:%{_prefix}/local/bin/tox-bootstrapd:%{_bindir}/tox-bootstrapd:g' other/bootstrap_daemon/tox-bootstrapd.service
# change user and of bootstrapd
sed -ri 's:User=tox-bootstrapd:User=tox:g' other/bootstrap_daemon/tox-bootstrapd.service
sed -ri 's:Group=tox-bootstrapd:Group=toxcmd:g' other/bootstrap_daemon/tox-bootstrapd.service
# change location of bootstrap kyes
sed -ri 's:%{_localstatedir}/lib/tox-bootstrapd/keys:%{_sysconfdir}/tox/bootstrapd/keys:g' other/bootstrap_daemon/tox-bootstrapd.conf

%build
autoreconf -i
%configure \
            --enable-daemon \
            --enable-dht-bootstrap \
            --disable-static
make %{?_smp_mflags}

%install
%make_install

# Install dir /var/run/graylog2-server
install -d -m 0755 %{buildroot}%{_prefix}/lib/tmpfiles.d/
install -m 0644 %{SOURCE1} %{buildroot}%{_prefix}/lib/tmpfiles.d/tox-bootstrapd.conf

# Install dir /var/lib/tox-bootstrapd
install -d -m 0755 %{buildroot}%{_localstatedir}/lib/tox-bootstrapd/
# Install dir /etc/tox/bootstrapd/keys
install -d -m 0700 %{buildroot}%{_sysconfdir}/tox/bootstrapd/keys

# Install dir /etc and bootstrap-config
mkdir -p %{buildroot}/%{_sysconfdir}
install -D -m 0640 other/bootstrap_daemon/tox-bootstrapd.conf %{buildroot}%{_sysconfdir}/tox/bootstrapd/tox-bootstrapd.conf

# Install init-scripts
mkdir -p %{buildroot}/%{_sbindir}
install -D -m 0644 other/bootstrap_daemon/tox-bootstrapd.service %{buildroot}%{_unitdir}/tox-bootstrapd.service
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rctox-bootstrapd

# get rid of libtool files
rm %{buildroot}%{_libdir}/*.la

%pre daemon
%service_add_pre tox-bootstrapd.service
# create tox-bootstrapd group
if ! getent group toxcmd >/dev/null; then
        groupadd -r toxcmd
fi
# create tox-bootstrapd user
if ! getent passwd tox >/dev/null; then
        useradd -r -g toxcmd -d %{_localstatedir}/lib/tox-bootstrapd \
            -s /sbin/nologin -c "Tox Bootstrap" tox
fi

%post daemon
%service_add_post tox-bootstrapd.service
systemd-tmpfiles --create %{_prefix}/lib/tmpfiles.d/tox-bootstrapd.conf

%post -n libtoxav%{_soversion} -p /sbin/ldconfig
%post -n libtoxcore%{_soversion} -p /sbin/ldconfig
%post -n libtoxencryptsave%{_soversion} -p /sbin/ldconfig
%preun daemon
%service_del_preun tox-bootstrapd.service

%postun daemon
%service_del_postun tox-bootstrapd.service

%postun -n libtoxav%{_soversion} -p /sbin/ldconfig
%postun -n libtoxcore%{_soversion} -p /sbin/ldconfig
%postun -n libtoxencryptsave%{_soversion} -p /sbin/ldconfig

%files devel
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%dir %{_includedir}/tox
%{_includedir}/tox/*

%files
%license LICENSE.md
%doc README.md DONATORS CHANGELOG.md

%files daemon
%dir %{_sysconfdir}/tox
%dir %{_sysconfdir}/tox/bootstrapd
%config(noreplace) %{_sysconfdir}/tox/bootstrapd/tox-bootstrapd.conf
%{_bindir}/DHT_bootstrap
%{_bindir}/tox-bootstrapd
%{_unitdir}/tox-bootstrapd.service
%{_tmpfilesdir}/tox-bootstrapd.conf
%{_sbindir}/rctox-bootstrapd
%dir %{_localstatedir}/lib/tox-bootstrapd
%dir %attr(0770,tox,toxcmd) %{_sysconfdir}/tox/bootstrapd/keys

%files -n libtoxav%{_soversion}
%{_libdir}/libtoxav.so.%{_soversion}*

%files -n libtoxcore%{_soversion}
%{_libdir}/libtoxcore.so.%{_soversion}*

%files -n libtoxencryptsave%{_soversion}
%{_libdir}/libtoxencryptsave.so.%{_soversion}*

%changelog
* Wed Apr 18 2018 ecsos@opensuse.org
- update to 0.2.2
  - #872 Restrict packet kinds that can be sent through onion path.
  - #864 CMake warn if libconfig not found
  - #863 Remove broken and unmaintained scripts.
  - #859 Add clarifying comment to cryptpacket_received function.
  - #857 Avoid the use of rand() in tests.
  - #846 Disallow stderr logger by default.
  - #845 Fix coveralls reporting.
  - #844 Add COVERAGE cmake flag for clang.
  - #825 Add default stderr logger for logging to nullptr.
  - #824 Simplify sendpacket function, deduplicate some logic.
  - #809 Remove the use of the 'hh' format specifier.
  - #801 Add logging to the onion_test.
  - #797 Move struct DHT_Friend into DHT.c.
* Sun Apr  8 2018 ecsos@opensuse.org
- fix build failure for Leap 42.3
* Sun Apr  1 2018 sleep_walker@opensuse.org
- dependency cleanup
- get rid of static libraries completely
- disable ldconfig for non-libraries packages
* Thu Mar 22 2018 sleep_walker@opensuse.org
- fix license file name, put into %%license section
- drop libtoxdns subpackage
- get rid of libtool files
- add GPG signature of the sources
- fix source file name
* Tue Mar 20 2018 ecsos@opensuse.org
- update to 0.2.1
  * Merged PRs:
  - #837 Update version to 0.2.1.
  - #833 Add missing tox_nospam_size() function
  - #832 Don't set RTP_LARGE_FRAME on rtp audio packets
  - #831 Don't throw away rtp packets from old Toxcore
  - #828 Make file transfers 50%% faster.
- changes from 0.2.0
  * Merged PRs:
  - #821 Remove deprecated conference namelist change callback.
  - #820 Fix auto_tests to stop using the deprecated conference
    API.
  - #819 Change default username to empty string
  - #818 Change README to talk about cmake instead of autoreconf.
  - #817 Fix warning on Mac OS X and FreeBSD.
  - #815 Some minor cleanups suggested by cppcheck.
  - #814 Fix memory leak of Logger instance on error paths.
  - #813 Minor cleanups: dead stores and avoiding complex macros.
  - #808 Fix a bunch of compiler warnings and remove
    suppressions.
  - #807 Link all tests to the android cpufeatures library if
    available.
  - #806 Fix toxcore.pc generation.
  - #805 Add an option that allows us to specify that we require
    toxav.
  - #804 Fix OSX tests: find(1) doesn't work like on Linux.
  - #803 Fix the windows build: pthread needs to be linked after
    vpx.
  - #800 Make group number in the toxav public API uint32_t
  - #799 Implement the "persistent conference" callback changes
    as new functions.
  - #798 Add deprecation notices to functions that will go away
    in v0.3.0.
  - #796 Make some sizeof tests linux-only.
  - #794 Remove apidsl from the build.
  - #793 Add a bazel test that ensures all our projects are
    GPL-3.0.
  - #792 Increase range of ports available to Toxes during tests
  - #791 Run all tests in parallel on Travis.
  - #790 Disable lan discovery in most tests.
  - #789 Remove tox_test from autotools build.
  - #788 Don't print trace level logging in tests.
  - #787 Split up tox_test into multiple smaller tests
  - #783 Send 0 as peer number in CHANGE_OCCURRED group event.
  - #782 Use const more in C code.
  - #781 Don't build all the small sub-libraries.
  - #780 Get rid of the only GNU extension we used.
  - #779 Remove leftover symmetric key from DHT struct.
  - #778 Add static asserts for all the struct sizes in toxcore.
  - #776 Optionally use newer cmake features.
  - #774 Improve gtest finding, support local checkout.
  - #773 Add gtest include directory to -I flags if found.
  - #772 Reject discovery packets coming from outside the "LAN".
  - #771 Adopt the "change occurred" API change from
    isotoxin-groupchat.
  - #770 Add MSVC compilation instructions
  - #767 Build toxcore with libsodium.dll instead of
    libsodium.lib.
  - #766 Remove libcheck from the dependencies.
  - #764 Fix LAN discovery on FreeBSD.
  - #760 Make cmake script more forgiving.
  - #759 Use more ubuntu packages; remove hstox for now.
  - #757 Improve stability of crypto_memcmp test.
  - #756 Format .cpp files with format-source.
  - #755 Add some unit tests for util.h.
  - #754 Move the tox_sync tool to the toxins repository.
  - #753 Move irc_syncbot to the toxins repository.
  - #752 Move tox_shell program to the toxins repository.
  - #751 Use the markdown GPLv3 license in the c-toxcore repo.
  - #750 Remove csrc from the RTPHeader struct.
  - #748 Revert "Add correction message type"
  - #745 Change the "capabilities" field to a "flags" field.
  - #742 Improve conference test stability.
  - #741 Add -D__STDC_LIMIT_MACROS=1 for C++ code.
  - #739 Add RTP header fields for the full frame length and
    offset.
  - #737 Use nullptr as NULL pointer constant instead of NULL
    or 0.
  - #736 Avoid clashes with "build" directories on
    case-insensitive file systems.
  - #734 Make audio/video bit rates "properties"
  - #733 Fix link in README.md
  - #730 Fix out of bounds read in error case in messenger_test.
  - #729 Remove dead return statement.
  - #728 Disable the autotools build in PR builds.
  - #727 Rename some rtp header struct members to be clearer.
  - #725 Publish a single public BUILD target for c-toxcore.
  - #723 Use <stdlib.h> for alloca on FreeBSD.
  - #722 Use self-built portaudio instead of system-provided.
  - #721 Manually serialise RTPHeader struct instead of memcpy.
  - #718 Improve sending of large video frames in toxav.
  - #716 Add comment from #629 in ring_buffer.c.
  - #714 Make BUILD files more finely-grained.
  - #713 Add BUILD files for all the little tools in the repo.
  - #711 Make the monolith test a C++ binary.
  - #710 Don't allocate or dereference Tox_Options in tests.
  - #709 Remove nTox from the repo.
  - #708 Add testing/*.c (except av_test) to bazel build.
  - #707 Fix log message in simple_conference_test:
    invite -> message.
  - #703 Add a simple conference test with 3 friends.
  - #701 Add astyle to Circle CI build.
  - #700 Use more descriptive names in bwcontroller.
  - #699 Add some explanatory comments to the toxav audio code.
  - #698 Extract named constants from magic numbers in
    toxav/audio.c.
  - #697 Use C99 standard in bazel builds.
  - #694 Add bazel build scripts for c-toxcore.
  - #693 Make libcheck optional for windows builds.
  - #691 Don't install packages needlessly on Travis
  - #690 Run fewer Travis jobs during Pull Requests.
  - #689 Make Net_Crypto a module-private type.
  - #688 Make DHT a module-private type.
  - #687 Use apidsl to generate LAN_discovery.h.
  - #686 Remove hstox test for now.
  - #685 Add message type for correction
  - #684 Add random_u16 function and rename the others to match.
  - #682 Use larger arrays in crypto timing tests.
  - #681 Fix some memory or file descriptor leaks in test code.
  - #680 Filter out annoying log statements in unit tests.
  - #679 Use apidsl to generate ping.h.
  - #678 Sort monolith.h according to ls(1): uppercase first.
  - #677 Make pack/unpack_ip_port public DHT functions.
  - #675 Make Onion_Announce a module-private type.
  - #674 Make TCP_Client_Connection a module-private type.
  - #673 Move TCP_Secure_Connection from .h to .c file.
  - #672 Make Friend_Connections a module-private type.
  - #670 Make Friend_Requests a module-private type.
  - #669 Make Onion_Client a module-private type.
  - #668 Make Ping_Array a module-private type.
  - #667 pkg-config .pc files: added .private versions of Libs
    and Required
  - #665 Remove useless if statement
  - #662 Move Networking_Core struct into the .c file.
  - #661 Disable asan, since it seems to break on travis.
  - #660 Increase test retries to 10 (basically infinite).
  - #659 Fix formatting in some C files.
  - #658 Call freeaddrinfo on error paths in net_getipport.
  - #657 Zero-initialise stack-allocated objects in hstox driver.
  - #656 Fix file descriptor leak in hstox test.
  - #652 Add support for building the monolith test on android.
  - #650 Remove deprecated ToxDNS
  - #648 Make hstox compile on FreeBSD
  - #624 Update rpm spec and use variables in cmake instead of
    hardcoded paths
  - #616 Add projects link to Readme.
  - #613 Fix travis
  - #605 Fix OS X Travis.
  - #598 Fix typos in docs
  - #578 Split toxav_bit_rate_set() into two functions to hold
    the maximum bitrates libvpx supports
  - #477 Update install instructions to use CMake
  - #465 Add Alpine linux Dockerfile in addition to the existing
    Debian one
  - #442 Generate only one large library "libtoxcore".
  - #334 Change toxencryptsave API to never overwrite pass keys.
  * Closed issues:
  - #704 Add CORRECTION support to group chats
  - #620 Video bug: large video frames are not sent correctly
  - #606 groupId is int whereas friendId is uint32_t, reason?
  - #572 int32_t may be not large enough as a argument for
    video_bit_rate of vp8/9 codec
  - #566 LAYER #: modules for static linking - build issue
  - #42 Remove ToxDNS and related stuff from toxcore
* Wed Dec 27 2017 sleep_walker@opensuse.org
- rename from toxcore to c-toxcore
- update to 0.1.11
  * Merged PRs:
  - #643 Add .editorconfig
  - #637 Update tox-bootstrapd Dockerfile
  - #635 Separate FreeBSD Travis build in 2 stages
  - #632 Lift libconfig to v1.7.1
  - #631 Add aspcud for Opam
  - #630 Fix for Travis fail on addr_resolve testing
  - #623 Split video payload into multiple RTP messages when too
    big to fit into one
  - #615 forget DHT pubkey of offline friend after DHT timeout
  - #611 Fix typo
  - #607 set onion pingid timeout to announce timeout (300s)
  - #592 Adjust docs of few toxencrypt function to the code
  - #587 Fix tox test
  - #586 Improve LAN discovery
  - #576 Replace include(CTest) on enable_testing()
  - #574 Reset hole-punching parameters after not punching for
    a while
  - #571 Configure needs to find libsodium headers.
  - #515 Network cleanup: reduce dependency on system-defined
    constants
  - #505 Add FreeBSD Travis
  - #500 Fixed the bug when receipts for messages sent from the
    receipt callback never arrived.
  * Closed issues:
  - #493 Receipts for messages sent from the receipt callback
    never arrive
- drop msi.c_no-return-in-nonvoid-function.patch
* Wed Aug 30 2017 ecsos@opensuse.org
- update to 0.1.10
  * Merged PRs:
  - #564 Fix Windows build
  - #542 Save bandwidth by moderating onion pinging
* Sun Jun 11 2017 ecsos@opensuse.org
- update to 0.1.9
  * Merged PRs:
  - #561 Remove unused variable
  - #560 Fix non-portable zeroing out of doubles
  - #559 Fix theoretical memory leaks
  - #557 Document inverted mutex lock/unlock.
  - #556 Build tests on appveyor, the MSVC build, but don't run
    them yet.
  - #555 Fold hstox tests into the general linux test.
  - #554 Add a monolith_test that includes all toxcore sources.
  - #553 Factor out strict_abi cmake code into a separate module.
  - #552 Fix formatting and spelling in version-sync script.
  - #551 Forbid undefined symbols in shared libraries.
  - #546 Make variable names in file saving test less cryptic
  - #539 Make OSX test failures fail the Travis CI build.
  - #537 Fix TokTok/c-toxcore#535
  - #534 Fix markdown formatting
  - #530 Implement missing TES constant functions.
  - #511 Save bandwidth by avoiding superfluous Nodes Requests to
    peers already on the Close List
  - #506 Add test case for title change
  - #498 DHT refactoring
  - #487 Split daemon's logging backends in separate modules
  - #468 Test for memberlist not changing after changing own name
  - #449 Use new encoding of Maybe in msgpack results.
  * Closed issues:
  - #482 CMake can't detect and compile ToxAV on OSX
* Mon May  1 2017 ecsos@opensuse.org
- update to 0.1.8
  * Closed issues:
  - #535 OS X tests failing
  - #503 Undefined functions: tox_pass_salt_length,
    tox_pass_key_length, tox_pass_encryption_extra_length
  - #456 Tox.h doesn't expose the size of the nospam.
  - #411 Reduce CTest timeout to 2 minutes
  * Merged PRs:
  - #538 Reverting tox_loop PR changes
  - #526 Add TOX_NOSPAM_SIZE to the public API.
  - #525 Retry autotools tests the same way as cmake tests.
  - #524 Reduce ctest timeout to 2 minutes from 5 minutes.
  - #512 Add test for DHT pack_nodes and unpack_nodes
  - #504 CMake: install bootstrapd if it is built
  - #488 Save compiled Android artifacts after CircleCI builds.
  - #473 Added missing includes: <netinet/in.h> and
    <sys/socket.h>
  - #335 Implement tox_loop
- update to 0.1.7
  * Closed issues:
  - #482 CMake can't detect and compile ToxAV on OSX
  * Merged PRs:
  - #521 Fix appveyor script: install curl from chocolatey.
  - #510 Fix list malloc(0) bug
  - #509 Fix network malloc(0) bug
  - #497 Fix network
  - #496 Fix Travis always succeeding despite tests failing
  - #491 Add crypto_memzero for temp buffer
  - #490 Move c_sleep to helpers.h and misc_tools.h
  - #486 Remove empty line in Messenger.c
  - #483 Make BUILD_TOXAV an option and fail if dependencies are
    missing
  - #481 Remove dependency on strings.h
  - #480 Use VLA macro
  - #479 Fix pthreads in AppVeyor build
  - #471 Remove statics used in onion comparison functions.
  - #461 Replace part of network functions on
    platform-independent implementation
  - #452 Add VLA compatibility macro for C89-ish compilers.
* Sun Feb  5 2017 ecsos@opensuse.org
- update to 0.1.6
  * Closed issues:
  - #415 Set up a native windows build on appveyor
  - #124 Don't include OS specific headers in .h files
  * Merged PRs:
  - #460 Release v0.1.6.
  - #454 Add appveyor build for native windows tests.
  - #448 Only retry failed tests on Circle CI instead of all.
  - #434 Replace redundant packet type check in handler with
    assert.
  - #432 Remove some static variables
  - #385 Add platform-independent Socket and IP implementation
- update to 0.1.5
  * Merged PRs:
  - #447 Release v0.1.5.
  - #446 Limit number of retries to 3.
  - #445 Make Travis tests slightly more robust by re-running
    them.
  - #443 Make building DHT_bootstrap in cmake optional.
  - #433 Add tutorial and "danger: experimental" banner to
    README.
  - #431 Update license headers and remove redundant file name
    comment.
  - #424 Fixed the FreeBSD build failure due to the undefined
    MSG_NOSIGNAL.
  - #420 Setup autotools to read .so version info from a separate
    file
  - #418 Clarify how the autotools build is done on Travis.
* Fri Jan 13 2017 ecsos@opensuse.org
- update to 0.1.4
  * Closed issues:
  - #378 Replace all uses of make_quick_sort with qsort
  - #364 Delete misc_tools.h after replacing its use by qsort.
  - #363 Test against NaCl in addition to libsodium on Travis.
  * Merged PRs:
  - #422 Release v0.1.4.
  - #410 Fix NaCl build: tar was called incorrectly.
  - #409 Clarify that the pass key new function can fail.
  - #407 Don't use git.depth=1 anymore.
  - #404 Issue 404: semicolon not found
  - #403 Warn on -pedantic, don't error yet.
  - #401 Add logging callback to messenger_test.
  - #400 Run windows tests but ignore their failures.
  - #398 Portability Fixes
  - #397 Replace make_quick_sort with qsort
  - #396 Add an OSX build that doesn't run tests.
  - #394 CMake: Add soversion to library files to generate proper
    symlinks
  - #393 Set up autotools build to build against vanilla NaCl.
  - #392 Check that TCP connections aren't dropped in callbacks.
  - #391 Minor simplification in file_seek code.
  - #390 Always kill invalid file transfers when receiving file
    controls.
  - #388 Fix logging condition for IPv6 client timestamp updates.
  - #387 Eliminate dead return statement.
  - #386 Avoid accessing uninitialised memory in net_crypto.
  - #381 Remove TOX_DEBUG and have asserts always enabled.
- update to 0.1.3
  * Closed issues:
  - #347 Implement our own secure memcmp and memzero if libsodium
    isn't available
  * Merged PRs:
  - #395 Revert "Portability fixes"
  - #380 Test a few cmake option combinations before the build.
  - #377 Fix SSL verification in coveralls.
  - #376 Bring back autotools instructions
  - #373 Only fetch 1 revision from git during Travis builds.
  - #369 Integrate with CircleCI to build artifacts in the future
  - #366 Release v0.1.3.
  - #362 Remove .cabal-sandbox option from tox-spectest find
    line.
  - #361 Simplify integration as a third-party lib in cmake
    projects
  - #354 Add secure memcmp and memzero implementation.
  - #324 Do not compile and install DHT_bootstrap if it was
    disabled in configure
  - #297 Portability fixes
- update to 0.1.2
  * Closed issues:
  - #345 Array out of bounds read in "save" function
  - #342 Wrap all libsodium functions we use in toxcore in
    crypto_core.
  - #278 ToxAV use-after-free bug
  * Merged PRs:
  - #355 Release v0.1.2
  - #353 Fix toxav use after free caused by premature MSI
    destruction
  - #346 Avoid array out of bounds read in friend saving.
  - #344 Remove unused get/set salt/key functions from
    toxencryptsave.
  - #343 Wrap all sodium/nacl functions in crypto_core.c.
  - #341 Add test to check if tox_new/tox_kill leaks.
  - #336 Correct TES docs to reflect how many bytes functions
    actually require.
  - #333 Use tox_options_set_* instead of direct member access.
- update to 0.1.1
  * Closed issues:
  - #327 The TOX_VERSION_REQUIRE macro is broken.
  - #221 Option to disable local peer detection
  * Merged PRs:
  - #337 Release v0.1.1
  - #332 Add test for encrypted savedata.
  - #330 Strengthen the note about ABI compatibility in tox.h.
  - #328 Drop the broken TOX_VERSION_REQUIRE macro.
  - #326 Fix unresolved reference in toxencryptsave API docs.
  - #309 Fixed attempt to join detached threads
    (fixes toxav test crash)
  - #306 Add option to disable local peer discovery
- migrate to fork https://github.com/toktok/c-toxcore
  Original was https://github.com/irungentoo/toxcore
* Tue Sep  1 2015 ecsos@opensuse.org
- change location of bootstrap daemon cfg
- change user and group of bootstrap damon
* Thu Aug 27 2015 ecsos@opensuse.org
- update to git from 08.08.2015
- seperate librarys
- insert systemd-services fpr bootstrapd
* Tue Sep 23 2014 ecsos@schirra.net
- remove msi.c_no-return-in-nonvoid-function.patch
* Mon Jun 23 2014 ecsos@schirra.net
- update to git from 23.06.2014
* Sun Feb 23 2014 ecsos@schirra.net
- update to ProjectTox-Core-f219fb4ac1bf60eea3117df4aa8615cd07738a69
* Sat Aug  3 2013 novell@tower-net.de
- Update to ProjectTox-Core-aa78644aed020198f85c97fe63bea7fc88e4a8dc
* Fri Aug  2 2013 novell@tower-net.de
- Modified CMakeLists_curses_ncurses_link_typo.patch
* Fri Aug  2 2013 novell@tower-net.de
- Updated to tox-7379392d80
* Wed Jul 31 2013 novell@tower-net.de
- CMakeLists_curses_ncurses_link_typo.patch fixes a typo to link with libncurses
* Tue Jul 30 2013 novell@tower-net.de
- New tox https://github.com/irungentoo/ProjectTox-Core/commit/b94d9d6765381e0a80f86a85edf45b1fd652a21a
